==> haskell-rio-prettyprint-0.1.8.0-62-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-prettyprint
version:              0.1.8.0
visibility:           public
id:                   rio-prettyprint-0.1.8.0-4VEed9eIFha1YPzhahlWIJ
key:                  rio-prettyprint-0.1.8.0-4VEed9eIFha1YPzhahlWIJ
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  0de8ac094a384d6535de45ca33979744
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.8.0-4VEed9eIFha1YPzhahlWIJ
depends:
    Cabal-3.10.3.0 aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh array-0.5.6.0
    base-4.18.2.1 colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z mtl-2.3.1
    path-0.9.6-JZJSfxZgLNX9Y539GdP67P
    rio-0.1.24.0-FBO4PrA6UlqFqVtMb3OxSz text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.8.0-64-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-prettyprint
version:              0.1.8.0
visibility:           public
id:                   rio-prettyprint-0.1.8.0-HdRcgeWmvcfKcoZxpVmw1t
key:                  rio-prettyprint-0.1.8.0-HdRcgeWmvcfKcoZxpVmw1t
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  faac94d8dde815d327865f376443e0c8
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.8.0-HdRcgeWmvcfKcoZxpVmw1t
depends:
    Cabal-3.10.3.0 aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-IMcNZ5h2aza3c3hvu2tQms array-0.5.6.0
    base-4.18.2.1 colour-2.3.6-3w6KTKXw4UOJxMlHZXmqB6 mtl-2.3.1
    path-0.9.6-BfPc0tTnWDFIco9YzxzKzp
    rio-0.1.24.0-KVtH5Pu4lMV2pIyCm3kd0p text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
